==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Nicht unterstütze Kompressionsmethode</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Kompressionssetup fehlgeschlagen</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Stream Kompression</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Erlaubt das Komprimieren eines Streams von Nachrichten, die vom Server gesendet und empfangen wurden</translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Ungültiges Kompressionslevel</translation>
    </message>
    <message>
        <source>invalid or incomplete deflate data</source>
        <translation>ungültige oder unvollständige Entpackungsdaten</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Nicht genügend Speicher für Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Zlib Versionskonflikt!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Falsche Kompressions Verhandlungsantwort</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Nicht unterstütze Kompressionsmethode</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Kompressionssetup fehlgeschlagen</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Datenstromkompression</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Erlaubt das Komprimieren eines Nachrichten Datenstroms zum/vom Server</translation>
    </message>
    <message>
        <source>Enable data compression transferred between client and server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Ungültiger Kompressionslevel</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Nicht genügend Speicher für Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Zlib Versionskonflikt!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Fehlerhafte Kompressionsaushandlung</translation>
    </message>
    <message>
        <source>Invalid or incomplete deflate data</source>
        <translation>Falsche oder unvollständige Kompressionsdaten</translation>
    </message>
    <message>
        <source>Unknown Zlib error, %1</source>
        <translation>Unbekannter Zlib Fehler, %1</translation>
    </message>
</context>
</TS>
